<?php
$page_title = "Notice Details";
include_once('template/base_head.php');
?>
			<!-- サイドバー -->
			<aside id="colLeft">
				<h1><a href=""><img src="../img/logo.png" alt="iWallet"></a></h1>
				<div class="aside-heading">
					&nbsp;
				</div>
				&nbsp;
			</aside>
			<!-- /サイドバー -->
			<!-- メインカラム -->
			<div id="colMain">
				<div class="mainIn">
					<?php include_once('template/base_nav.php'); ?>
					<form id="acForm" action="" method="post">
					<article>
						<div class="article-heading">
							<h2><?php echo $page_title; ?></h2>
						</div>
						<?php $this -> echoMessage(); ?>
						<table class="table col bdr default odd w60p fontXS m_auto mb20">
							<colgroup>
								<col class="w20p">
								<col class="w80p">
							</colgroup>
							<tr>
								<th>Release Date</th>
								<td><input type="text" name="expose_time" id="expose_time" value="<?php $this -> echoExposeTime(); ?>" class="px110" ></td>
							</tr>
							<tr>
								<th>Title</th>
								<td><input type="text" name="title" id="title" value="<?php $this -> echoTitle(); ?>" class="w100p"></td>
							</tr>
							<tr>
								<th>Article</th>
								<td>
									<textarea rows="40" class="w100p" name="body" id="body"><?php $this -> echoBody(); ?></textarea>
								</td>
							</tr>
							<tr>
								<th>Language</th>
								<td>
									<label class="newslist"><input type="radio" name="langage" id="langage" value="1" <?php $this -> echoLangageValue(1); ?>> en</label>
									<label class="newslist"><input type="radio" name="langage" id="langage" value="4" <?php $this -> echoLangageValue(4); ?>> id</label>
									<label class="newslist"><input type="radio" name="langage" id="langage" value="0" <?php $this -> echoLangageValue(0); ?>> ja</label>
									<label class="newslist"><input type="radio" name="langage" id="langage" value="2" <?php $this -> echoLangageValue(2); ?>> sc</label>
									<label class="newslist"><input type="radio" name="langage" id="langage" value="3" <?php $this -> echoLangageValue(3); ?>> tc</label>
								</td>
							</tr>
							<tr>
								<th>Site</th>
								<td>
									<label class="newslist"><input type="radio" name="site_flg" id="site_flg" value="0" <?php $this -> echoSiteFlgValue(0); ?>> iWallet</label>
									<label class="newslist"><input type="radio" name="site_flg" id="site_flg" value="1" <?php $this -> echoSiteFlgValue(1); ?>> D-Wallet</label>
								</td>
							</tr>
						</table>
						<p class="calign">
							<a id="btnList" class="btn bg-default">&laquo; Back</a>&emsp;
							<input type="button" id="btnConfirm" value="Preview" class="btn bg-grad px100 hi25">&emsp;
							<?php $this -> echoButton(); ?>
						</p>
						<div class="article-bottom">
						</div>
					</article>
					<input type="hidden" value="" id="type" name="type" />
					<input type="hidden" value="<?php $this -> echoNId(); ?>" id="n_id" name="n_id" />
					<?php $this -> echoTranslationData("/news") ?>
					</form>
				</div>
			</div>
			<!-- /メインカラム -->
		</div>
		<?php include_once('template/base_foot.php'); ?>
	</div>
	<script src="../js/news.js"></script>
</body>
</html>
